@@ -1,5 +1,4 @@
-"""
-Implementation of JSONEncoder
+"""Implementation of JSONEncoder
 """
 import re
 
@@ -32,8 +31,8 @@ INFINITY = float('1e66666')
 FLOAT_REPR = repr
 
 def encode_basestring(s):
-    """
-    Return a JSON representation of a Python string
+    """Return a JSON representation of a Python string
+
     """
     def replace(match):
         return ESCAPE_DCT[match.group(0)]
@@ -41,6 +40,9 @@ def encode_basestring(s):
 
 
 def py_encode_basestring_ascii(s):
+    """Return an ASCII-only JSON representation of a Python string
+
+    """
     if isinstance(s, str) and HAS_UTF8.search(s) is not None:
         s = s.decode('utf-8')
     def replace(match):
@@ -63,11 +65,10 @@ def py_encode_basestring_ascii(s):
 encode_basestring_ascii = c_encode_basestring_ascii or py_encode_basestring_ascii
 
 class JSONEncoder(object):
-    """
-    Extensible JSON <http://json.org> encoder for Python data structures.
+    """Extensible JSON <http://json.org> encoder for Python data structures.
 
     Supports the following objects and types by default:
-    
+
     +-------------------+---------------+
     | Python            | JSON          |
     +===================+===============+
@@ -90,35 +91,34 @@ class JSONEncoder(object):
     ``.default()`` method with another method that returns a serializable
     object for ``o`` if possible, otherwise it should call the superclass
     implementation (to raise ``TypeError``).
+
     """
-    __all__ = ['__init__', 'default', 'encode', 'iterencode']
     item_separator = ', '
     key_separator = ': '
     def __init__(self, skipkeys=False, ensure_ascii=True,
             check_circular=True, allow_nan=True, sort_keys=False,
             indent=None, separators=None, encoding='utf-8', default=None):
-        """
-        Constructor for JSONEncoder, with sensible defaults.
+        """Constructor for JSONEncoder, with sensible defaults.
 
-        If skipkeys is False, then it is a TypeError to attempt
+        If skipkeys is false, then it is a TypeError to attempt
         encoding of keys that are not str, int, long, float or None.  If
         skipkeys is True, such items are simply skipped.
 
-        If ensure_ascii is True, the output is guaranteed to be str
+        If ensure_ascii is true, the output is guaranteed to be str
         objects with all incoming unicode characters escaped.  If
         ensure_ascii is false, the output will be unicode object.
 
-        If check_circular is True, then lists, dicts, and custom encoded
+        If check_circular is true, then lists, dicts, and custom encoded
         objects will be checked for circular references during encoding to
         prevent an infinite recursion (which would cause an OverflowError).
         Otherwise, no such check takes place.
 
-        If allow_nan is True, then NaN, Infinity, and -Infinity will be
+        If allow_nan is true, then NaN, Infinity, and -Infinity will be
         encoded as such.  This behavior is not JSON specification compliant,
         but is consistent with most JavaScript based encoders and decoders.
         Otherwise, it will be a ValueError to encode such floats.
 
-        If sort_keys is True, then the output of dictionaries will be
+        If sort_keys is true, then the output of dictionaries will be
         sorted by key; this is useful for regression tests to ensure
         that JSON serializations can be compared on a day-to-day basis.
 
@@ -138,6 +138,7 @@ class JSONEncoder(object):
         If encoding is not None, then all input strings will be
         transformed into unicode using that encoding prior to JSON-encoding.
         The default is UTF-8.
+
         """
 
         self.skipkeys = skipkeys
@@ -153,14 +154,13 @@ class JSONEncoder(object):
         self.encoding = encoding
 
     def default(self, o):
-        """
-        Implement this method in a subclass such that it returns
+        """Implement this method in a subclass such that it returns
         a serializable object for ``o``, or calls the base implementation
         (to raise a ``TypeError``).
 
         For example, to support arbitrary iterators, you could
         implement default like this::
-            
+
             def default(self, o):
                 try:
                     iterable = iter(o)
@@ -169,21 +169,22 @@ class JSONEncoder(object):
                 else:
                     return list(iterable)
                 return JSONEncoder.default(self, o)
+
         """
         raise TypeError("%r is not JSON serializable" % (o,))
 
     def encode(self, o):
-        """
-        Return a JSON string representation of a Python data structure.
+        """Return a JSON string representation of a Python data structure.
 
         >>> JSONEncoder().encode({"foo": ["bar", "baz"]})
         '{"foo": ["bar", "baz"]}'
+
         """
         # This is for extremely simple cases and benchmarks.
         if isinstance(o, basestring):
             if isinstance(o, str):
                 _encoding = self.encoding
-                if (_encoding is not None 
+                if (_encoding is not None
                         and not (_encoding == 'utf-8')):
                     o = o.decode(_encoding)
             if self.ensure_ascii:
@@ -199,14 +200,14 @@ class JSONEncoder(object):
         return ''.join(chunks)
 
     def iterencode(self, o, _one_shot=False):
-        """
-        Encode the given object and yield each string
+        """Encode the given object and yield each string
         representation as available.
-        
+
         For example::
-            
+
             for chunk in JSONEncoder().iterencode(bigobject):
                 mysocket.write(chunk)
+
         """
         if self.check_circular:
             markers = {}
@@ -240,8 +241,8 @@ class JSONEncoder(object):
                     % (o,))
 
             return text
-        
-        
+
+
         if _one_shot and c_make_encoder is not None and not self.indent and not self.sort_keys:
             _iterencode = c_make_encoder(
                 markers, self.default, _encoder, self.indent,
@@ -355,14 +356,14 @@ def _make_iterencode(markers, _default, _encoder, _indent, _floatstr, _key_separ
             # also allow them.  Many encoders seem to do something like this.
             elif isinstance(key, float):
                 key = _floatstr(key)
-            elif isinstance(key, (int, long)):
-                key = str(key)
             elif key is True:
                 key = 'true'
             elif key is False:
                 key = 'false'
             elif key is None:
                 key = 'null'
+            elif isinstance(key, (int, long)):
+                key = str(key)
             elif _skipkeys:
                 continue
             else:
@@ -433,7 +434,3 @@ def _make_iterencode(markers, _default, _encoder, _indent, _floatstr, _key_separ
                 del markers[markerid]
 
     return _iterencode
-
-
-
-__all__ = ['JSONEncoder']
